@@ -62,14 +62,10 @@ class ActionsMixIn:
         parameters = []
         for action in self.api_json()['actions']:
             if 'parameters' in action:
-                for raw in action['parameters']:
-                    parameters.append(Parameter(raw['_class'], raw['name'],
-                                                raw.get('value', '')))
+                parameters.extend(Parameter(raw['_class'], raw['name'], raw.get(
+                    'value', '')) for raw in action['parameters'])
                 break
         return parameters
 
     def get_causes(self):
-        for action in self.api_json()['actions']:
-            if 'causes' in action:
-                return action['causes']
-        return []
+        return next((action['causes'] for action in self.api_json()['actions'] if 'causes' in action), [])
